imblearn.under_sampling.RepeatedEditedNearestNeighbours
=======================================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: RepeatedEditedNearestNeighbours

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RepeatedEditedNearestNeighbours.__init__
      ~RepeatedEditedNearestNeighbours.fit
      ~RepeatedEditedNearestNeighbours.fit_sample
      ~RepeatedEditedNearestNeighbours.get_params
      ~RepeatedEditedNearestNeighbours.sample
      ~RepeatedEditedNearestNeighbours.set_params
   
   

   
   
   